import { Injectable, Inject } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';

import { Observable } from 'rxjs/Observable';

import 'rxjs/add/operator/do';
import 'rxjs/add/operator/timeout';

@Injectable()
export class RESTService {
  private baseURL: string;
  private readonly httpHeaders: HttpHeaders;

  constructor(
    @Inject(HttpClient) private _httpClient: HttpClient,
  ) {
    this.baseURL = 'http://192.168.1.101:80/webapp';
    this.httpHeaders = new HttpHeaders()
      .set('Accept', 'application/json')
      .set('Content-Type', 'application/json');
  }

  public get httpClient(): HttpClient {
    return this._httpClient;
  }

  public get<T>(entry: string, params?: {[param: string]: string | string[]}): Observable<T> {
    const headers: HttpHeaders = this.httpHeaders;

    return this._httpClient
      .get<T>(`${this.baseURL}${entry}`, {
        headers: headers,
        params: params,
        responseType: 'json',
      });
  }

  public post<T>(entry: string, body: any | null, params?: {[param: string]: string | string[]}): Observable<T> {
    const headers: HttpHeaders = this.httpHeaders;

    return this._httpClient
      .post<T>(`${this.baseURL}${entry}`, body, {
        headers: headers,
        params: params,
        responseType: 'json',
      });
  }

}
