import { Injectable } from '@angular/core';
import { Router } from '@angular/router';

import { Effect, Actions, ofType } from '@ngrx/effects';
import { Action } from '@ngrx/store';

import { Observable } from 'rxjs/Observable';
import { of } from 'rxjs/observable/of';

import 'rxjs/add/operator/catch';
import 'rxjs/add/operator/do';
import 'rxjs/add/operator/exhaustMap';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/take';

import { Member } from '../../model/member';
import { MemberService } from '../../service/member.service';

import {
  Signin,
  SigninSuccess,
  SigninFailure,
  ActionType,
} from './auth.action';

@Injectable()
export class Effects {

  constructor(
    private actions$: Actions,
    private memberService: MemberService,
    private router: Router
  ) { }

  @Effect()
  signin$: Observable<Action> = this.actions$
    .ofType(ActionType.Signin)
    .map((action: Signin) => action.payload)
    .exhaustMap(payload =>
      this.memberService
        .signin(payload.email, payload.password)
        .map(member => new SigninSuccess(member))
        .catch(error => of(new SigninFailure(error)))
    );

  @Effect({ dispatch: false })
  signinSuccess$ = this.actions$
    .ofType(ActionType.SigninSuccess)
    .do(() => this.router.navigate(['/']));

  @Effect({ dispatch: false })
  signinRedirect$ = this.actions$
    .ofType(ActionType.SigninRedirect, ActionType.Signout)
    .do(authed => {
      this.router.navigate(['/login']);
    });

}
